@@ -139,6 +139,7 @@ class SimbaRequest(object):
             auth_flow=settings().AUTH_FLOW,
             client_id=settings().AUTH_CLIENT_ID,
             client_secret=settings().AUTH_CLIENT_SECRET,
+            provider=settings().AUTH_PROVIDER,
         )
 
     @property
@@ -208,8 +209,7 @@ class SimbaRequest(object):
         if not authenticated:
             return headers
         _ = PROVIDERS[login.auth_flow].login_sync(
-            client_id=login.client_id,
-            client_secret=login.client_secret,
+            login=login,
             headers=headers,
             config=config,
         )
@@ -240,8 +240,7 @@ class SimbaRequest(object):
         if not authenticated:
             return headers
         _ = await PROVIDERS[login.auth_flow].login(
-            client_id=login.client_id,
-            client_secret=login.client_secret,
+            login=login,
             headers=headers,
             config=config,
         )
@@ -562,7 +561,7 @@ class SimbaRequest(object):
         self,
         headers: Optional[dict] = None,
         json_payload: Optional[dict] = None,
-        files: FileDict = None,
+        files: Optional[FileDict] = None,
         config: ConnectionConfig = None,
     ) -> dict:
         """
@@ -619,6 +618,12 @@ class SimbaRequest(object):
                         json=json_payload,
                         follow_redirects=True,
                     )
+            elif self.method == "DELETE":
+                response = await async_client.delete(
+                    self.url,
+                    headers=headers,
+                    follow_redirects=True,
+                )
             return self._process_response(response)
 
     def _process_response(self, response: Response) -> dict:
@@ -632,6 +637,10 @@ class SimbaRequest(object):
             if self._response.status_code:
                 self._status = self._response.status_code
 
+            # response.json does not properly handle DELETE, when response.content is not present
+            if not response.content:
+                response._content = b'{}'
+
             json_response = response.json()
             logger.info(
                 self.log_me(
