@@ -2217,7 +2217,11 @@ class SimbaSync:
                 )
                 if owner_identifier:
                     params.add_filter(
-                        FieldFilter(field="owner_identifier", op=FilterOp.EQ, value=owner_identifier)
+                        FieldFilter(
+                            field="owner_identifier",
+                            op=FilterOp.EQ,
+                            value=owner_identifier,
+                        )
                     )
             if alias:
                 params.add_filter(
@@ -2674,3 +2678,272 @@ class SimbaSync:
                     FieldFilter(op=FilterOp.EQ, field="event_name", value=event_name)
                 )
         return query_args
+
+    def create_secret(
+        self,
+        name: str,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/user/api_applications/``
+
+        create a user secret.
+
+        :param name: The secret name.
+        :type name: str
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a client secret
+        :rtype: dict
+        """
+        payload = {
+            "name": name,
+        }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.USER_SECRET,
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def get_secrets(
+        self,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> List[dict]:
+        """
+        GET ``/user/api_applications/``
+
+        Get user secrets.
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: client secrets
+        :rtype: list
+        """
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.USER_SECRET,
+            login=login,
+        ).retrieve_sync(config=config, headers=headers or {})
+
+    def admin_set_delegate(
+        self,
+        user: str,
+        delegate: bool,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/admin/users/{user}/delegate/``
+
+        Set the user as delegate.
+
+        :param user: The user ID.
+        :type user: str
+        :param delegate: To delegate or not.
+        :type delegate: bool
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a delegate setting.
+        :rtype: dict
+        """
+        payload = {
+            "delegate": delegate,
+        }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.ADMIN_DELEGATE.create(user),
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def admin_create_account(
+        self,
+        network: str,
+        alias: str,
+        owner: str,
+        owner_type: str,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/admin/accounts/``
+
+        Create a new account for a user.
+
+        :param network: The blockchain name.
+        :type network: str
+        :param alias: The account alias.
+        :type alias: str
+        :param owner: The account owner.
+        :type owner: str
+        :param owner_type: The account owner type. One of User or Organisation.
+        :type owner_type: str
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: an account object.
+        :rtype: dict
+        """
+
+        payload = {
+            "network": network,
+            "nickname": alias,
+            "alias": alias,
+            "owner": {"type": owner_type, "identifier": owner},
+        }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.ADMIN_ACCOUNTS,
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def admin_account_sign(
+        self,
+        network: str,
+        alias: str,
+        owner_identifier: str,
+        owner_type: str,
+        input_pairs: List[Tuple[str, Any]],
+        hash_message: Optional[bool] = False,
+        user_identifier: Optional[str] = None,
+        user_type: Optional[str] = None,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/admin/blockchain/{name}/sign/``
+
+        Sign on behalf of a user.
+
+        :param network: The blockchain name.
+        :type network: str
+        :param alias: The account alias.
+        :type alias: str
+        :param owner_identifier: The account owner.
+        :type owner_identifier: str
+        :param owner_type: The account owner type. One of User or Organisation.
+        :type owner_type: str
+        :param user_identifier: The requesting user.
+        :type user_identifier: str
+        :param user_type: The requesting user type. One of User or SimbaIdentity. Required if owner is an organisation.
+        :type user_type: Optional[str]
+        :param input_pairs: A list of tuples defining the data type and data to sign.
+        :type input_pairs: List[Tuple(str, Any)]
+        :param hash_message: Whether to hash the message before signing or not
+        :type hash_message: Optional[bool]. Default False
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a signed data structure.
+        :rtype: dict
+        """
+        if owner_type == "Organisation" and (not user_identifier or not user_type):
+            raise ValueError("Owner is an org but user or user type is not given.")
+        payload = {
+            "account": {
+                "identifier": {
+                    "type": "Alias",
+                    "value": alias
+                },
+                "owner": {
+                    "type": owner_type,
+                    "identifier": owner_identifier
+                }
+            },
+            "data": {
+                "input_pairs": [list(t) for t in input_pairs],
+                "hash_message": hash_message,
+            }
+        }
+        if owner_type == "Organisation":
+            payload["account"]["user"] = {
+                    "type": user_type,
+                    "identifier": user_identifier
+                }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.ADMIN_BLOCKCHAIN_SIGN.create(network),
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+    def admin_account_validate(
+        self,
+        network: str,
+        alias: str,
+        owner_identifier: str,
+        owner_type: str,
+        user_identifier: Optional[str] = None,
+        user_type: Optional[str] = None,
+        headers: Optional[dict] = None,
+        login: Login = None,
+        config: ConnectionConfig = None,
+    ) -> dict:
+        """
+        POST ``/admin/blockchain/{name}/validate/``
+
+        Validate the user has access to the given wallet.
+
+        :param network: The blockchain name.
+        :type network: str
+        :param alias: The account alias.
+        :type alias: str
+        :param owner_identifier: The account owner.
+        :type owner_identifier: str
+        :param owner_type: The account owner type. One of User or Organisation.
+        :type owner_type: str
+        :param user_identifier: The requesting user.
+        :type user_identifier: str
+        :param user_type: The requesting user type. One of User or SimbaIdentity. Required if owner is an organisation.
+        :type user_type: Optional[str]
+
+        :Keyword Arguments:
+            * **headers** (`Optional[dict]`) - additional http headers
+            * **login** (`Optional[Login]`)
+            * **config** (`Optional[ConnectionConfig]`)
+        :return: a signed data structure.
+        :rtype: dict
+        """
+        if owner_type == "Organisation" and (not user_identifier or not user_type):
+            raise ValueError("Owner is an org but user or user type is not given.")
+        payload = {
+            "account": {
+                "identifier": {
+                    "type": "Alias",
+                    "value": alias
+                },
+                "owner": {
+                    "type": owner_type,
+                    "identifier": owner_identifier
+                }
+            }
+        }
+        if owner_type == "Organisation":
+            payload["account"]["user"] = {
+                    "type": user_type,
+                    "identifier": user_identifier
+                }
+        return SimbaRequest(
+            method="POST",
+            endpoint=Path.ADMIN_BLOCKCHAIN_VALIDATE.create(network),
+            login=login,
+        ).send_sync(config=config, json_payload=payload, headers=headers or {})
+
+
