@@ -59,17 +59,21 @@ class Path(str, Enum):
     USER_FUND_ADDRESS = "/user/account/{}/fund/"
     USER_ADDRESS_BALANCE = "/user/account/{}/balance/{}/"
     ADMIN_WALLET_SET = "/admin/users/{}/wallet/set/"
+    ADMIN_BLOCKCHAIN_SIGN = "/admin/blockchain/{}/sign/"
+    ADMIN_BLOCKCHAIN_VALIDATE = "/admin/blockchain/{}/validate/"
     USER_WALLET_SET = "/user/wallet/set/"
     USER_WALLET = "/user/wallet/"
     USER_ACCOUNTS = "/user/accounts/"
     USER_ACCOUNT = "/user/accounts/{}/"
     USER_ACCOUNT_SIGN = "/user/accounts/{}/sign/"
+    USER_SECRET = "/user/api_applications/"
     USER_ACCOUNT_ADDRESS_SIGN = "/user/accounts/{}/sign/{}/"
     USER_ACCOUNT_SET = "/user/accounts/set/"
     ORGANISATION = "/v2/organisations/{}/"
     ORGANISATIONS = "/v2/organisations/"
     ORG_ACCOUNTS = "/v2/organisations/{}/accounts/"
     ADMIN_ACCOUNTS = "/admin/accounts/"
+    ADMIN_DELEGATE = "/admin/users/{}/delegate/"
     ORG_ACCOUNT = "/v2/organisations/{}/accounts/{}/"
     ORG_ACCOUNT_SIGN = "/v2/organisations/{}/accounts/{}/sign/"
     ORG_ACCOUNT_ADDRESS_SIGN = "/v2/organisations/{}/accounts/{}/sign/{}/"
